package
Version:
v0.0.0-...-1329d2c
Opens a new window with list of versions in this module.
Published: Feb 8, 2026
License: GPL-3.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func GetTermRowsCols() (rows, cols int, ok bool)
Gets size of the terminal
func IsPipedOutput() bool
Returns 'true' if output is being piped (Not char device)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.